@@ -35,11 +35,12 @@ use URI::URL;
 #-----------------------------------------------------------------------
 #	Public Global Variables
 #-----------------------------------------------------------------------
-use vars qw($VERSION $AUTOLOAD %OVERLOAD);
+use vars qw($VERSION $AUTOLOAD);
 
-$VERSION = '1.000';
+use overload '""' => 'as_string', 'fallback' => 1;
+
+$VERSION = '1.002';
 
-%OVERLOAD = ( '""' => 'as_string', 'fallback' => 1 );
 
 #-----------------------------------------------------------------------
 #	Private Global Variables
